==> Perinci-Examples-Bin-Classic-0.080.tar.gz: Perinci-Examples-Bin-Classic-0.080/lib/Perinci/Examples/Bin/Classic.pm <==
package Perinci::Examples::Bin::Classic;

our $DATE = '2020-04-29'; # DATE
our $VERSION = '0.080'; # VERSION

use 5.010001;

1;
# ABSTRACT: Perinci example CLI scripts (using Perinci::CmdLine::Classic)

__END__

=pod

=encoding UTF-8

=head1 NAME

Perinci::Examples::Bin::Classic - Perinci example CLI scripts (using Perinci::CmdLine::Classic)

=head1 VERSION

This document describes version 0.080 of Perinci::Examples::Bin::Classic (from Perl distribution Perinci-Examples-Bin-Classic), released on 2020-04-29.

=head1 DESCRIPTION

This distribution contains example scripts in C<bin/> which use
L<Perinci::CmdLine::Classic>. It was split from L<Perinci::Examples> so the
latter does not need to depend on Perinci::CmdLine::*.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Examples-Bin-Classic>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples-Bin-Classic>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Examples-Bin-Classic>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Perinci::CmdLine::Bin::Any>

L<Perinci::CmdLine::Bin::Lite>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2015, 2014, 2013, 2012 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Perinci-Examples-Bin-Classic-0.081.tar.gz: Perinci-Examples-Bin-Classic-0.081/lib/Perinci/Examples/Bin/Classic.pm <==
package Perinci::Examples::Bin::Classic;

our $DATE = '2021-01-30'; # DATE
our $VERSION = '0.081'; # VERSION

use 5.010001;

1;
# ABSTRACT: Perinci example CLI scripts (using Perinci::CmdLine::Classic)

__END__

=pod

=encoding UTF-8

=head1 NAME

Perinci::Examples::Bin::Classic - Perinci example CLI scripts (using Perinci::CmdLine::Classic)

=head1 VERSION

This document describes version 0.081 of Perinci::Examples::Bin::Classic (from Perl distribution Perinci-Examples-Bin-Classic), released on 2021-01-30.

=head1 DESCRIPTION

This distribution contains example scripts in C<bin/> which use
L<Perinci::CmdLine::Classic>. It was split from L<Perinci::Examples> so the
latter does not need to depend on Perinci::CmdLine::*.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Examples-Bin-Classic>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples-Bin>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Examples-Bin-Classic>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Perinci::CmdLine::Bin::Any>

L<Perinci::CmdLine::Bin::Lite>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2020, 2015, 2014, 2013, 2012 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
